@@ -6,14 +6,15 @@ import os.path
 import re
 import sys
 
-from sopel.tools import itervalues, get_command_regexp
+from sopel.tools import compile_rule, itervalues, get_command_regexp, get_nickname_command_regexp
+from sopel.config import core_section
+
+default_prefix = core_section.CoreSection.help_prefix.default
+del core_section
 
 if sys.version_info.major >= 3:
     basestring = (str, bytes)
 
-# Can be implementation-dependent
-_regex_type = type(re.compile(''))
-
 
 def get_module_description(path):
     good_file = (os.path.isfile(path) and
@@ -110,20 +111,6 @@ def enumerate_modules(config, show_all=False):
     return modules
 
 
-def compile_rule(nick, pattern):
-    # Not sure why this happens on reloads, but it shouldn't cause problems…
-    if isinstance(pattern, _regex_type):
-        return pattern
-
-    nick = re.escape(nick)
-    pattern = pattern.replace('$nickname', nick)
-    pattern = pattern.replace('$nick', r'{}[,:]\s+'.format(nick))
-    flags = re.IGNORECASE
-    if '\n' in pattern:
-        flags |= re.VERBOSE
-    return re.compile(pattern, flags)
-
-
 def trim_docstring(doc):
     """Get the docstring as a series of lines that can be sent"""
     if not doc:
@@ -149,6 +136,7 @@ def clean_callable(func, config):
     """Compiles the regexes, moves commands into func.rule, fixes up docs and
     puts them in func._docs, and sets defaults"""
     nick = config.core.nick
+    alias_nicks = config.core.alias_nicks
     prefix = config.core.prefix
     help_prefix = config.core.help_prefix
     func._docs = {}
@@ -173,22 +161,31 @@ def clean_callable(func, config):
     if hasattr(func, 'rule'):
         if isinstance(func.rule, basestring):
             func.rule = [func.rule]
-        func.rule = [compile_rule(nick, rule) for rule in func.rule]
+        func.rule = [compile_rule(nick, rule, alias_nicks) for rule in func.rule]
 
-    if hasattr(func, 'commands'):
+    if hasattr(func, 'commands') or hasattr(func, 'nickname_commands'):
         func.rule = getattr(func, 'rule', [])
-        for command in func.commands:
+        for command in getattr(func, 'commands', []):
             regexp = get_command_regexp(prefix, command)
             func.rule.append(regexp)
+        for command in getattr(func, 'nickname_commands', []):
+            regexp = get_nickname_command_regexp(nick, command, alias_nicks)
+            func.rule.append(regexp)
         if hasattr(func, 'example'):
             example = func.example[0]["example"]
             example = example.replace('$nickname', nick)
             if example[0] != help_prefix and not example.startswith(nick):
-                example = help_prefix + example[len(help_prefix):]
+                example = example.replace(default_prefix, help_prefix, 1)
         if doc or example:
-            for command in func.commands:
+            cmds = []
+            cmds.extend(getattr(func, 'commands', []))
+            cmds.extend(getattr(func, 'nickname_commands', []))
+            for command in cmds:
                 func._docs[command] = (doc, example)
 
+    if hasattr(func, 'intents'):
+        func.intents = [re.compile(intent, re.IGNORECASE) for intent in func.intents]
+
 
 def load_module(name, path, type_):
     """Load a module, and sort out the callables and shutdowns"""
@@ -203,7 +200,7 @@ def load_module(name, path, type_):
 
 
 def is_triggerable(obj):
-    return any(hasattr(obj, attr) for attr in ('rule', 'intent', 'commands'))
+    return any(hasattr(obj, attr) for attr in ('rule', 'intents', 'commands', 'nickname_commands'))
 
 
 def clean_module(module, config):
